set -e
inform_fd=2 

check_status() {
    local status="$?"
    if [ "$status" -ne 0 ]; then
	return "$status"
    fi
}

check_pipe2() {
    if [ "${PIPESTATUS[0]}" != "0" -o "${PIPESTATUS[1]}" != "0" ]; then
	return 1
    fi
}

error () {
    echo "$script: error: $@" >& $inform_fd
    exit 1
}

warning () {
    echo "$script: warning: $@" >& $inform_fd
}

copy_dir() {
    mkdir -p "$2"
    # Use tar, rather than cp -r, so that symlinks are preserved.
    (cd "$1" && tar cf - .) | (cd "$2" && tar xf -)
    check_pipe2
}

copy_dir_clean() {
    mkdir -p "$2"
    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	.) | (cd "$2" && tar xf -)
    check_pipe2
}

copy_dir_exclude() {
    local source="$1"
    local dest="$2"
    local excl="$3"
    shift 3
    mkdir -p "$dest"
    (cd "$source" && tar cfX - "$excl" "$@") | (cd "$dest" && tar xf -)
    check_pipe2
}

copy_dir_only() {
    local source="$1"
    local dest="$2"
    shift 2
    mkdir -p "$dest"
    (cd "$source" && tar cf - "$@") | (cd "$dest" && tar xf -)
    check_pipe2
}

clean_environment() {
    local env_var_list
    local var

    # Unset variables taken by bash from the environment in
    # noninteractive shells and affecting bash itself in undesirable
    # ways.  Other variables need only be unexported.
    unset BASH_ENV CDPATH POSIXLY_CORRECT TMOUT

    env_var_list=$(export | \
	grep '^declare -x ' | \
	sed -e 's/^declare -x //' -e 's/=.*//')

    for var in $env_var_list; do
	case $var in
	    CSL_SCRIPTDIR|HOME|LOGNAME|PWD|SHELL|SSH_*|TERM|USER)
		# These variables are OK to export and may be required
		# by this process or subprocesses.
		;;
	    LD_LIBRARY_PATH|PATH|XML_CATALOG_FILES)
		# PATH and LD_LIBRARY_PATH are set separately after
		# the release config has been read; see setup_path.
		;;
	    *)
		# On Cygwin, there are environment variables that cannot be unset, like "!C".
		export -n "$var" || true
		;;
	esac
    done

    # Use the C locale.
    export LANG=C
    export LC_ALL=C

    # Used for local CVS checkouts.
    export CVS_RSH=ssh

    # Ensure the shell running this script is also used for other
    # purposes.
    export SHELL=$BASH
    export CONFIG_SHELL=$BASH
}

pushenv() {
    pushenv_level=$(($pushenv_level + 1))
    eval pushenv_vars_${pushenv_level}=
}


pushenv_level=0
pushenv_vars_0=



pushenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    eval local pushenv_oldset=\"\${$pushenv_var+set}\"
    local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
    local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
    eval local pushenv_save_set=\"\${$pushenv_savep_var+set}\"
    if [ "$pushenv_save_set" = "set" ]; then
	error "Pushing $pushenv_var more than once at level $pushenv_level"
    fi
    if [ "$pushenv_oldset" = "set" ]; then
	eval $pushenv_save_var=\"\$pushenv_oldval\"
    else
	unset $pushenv_save_var
    fi
    eval $pushenv_savep_var=1
    eval export $pushenv_var=\"\$pushenv_newval\"
    local pushenv_list_var=pushenv_vars_${pushenv_level}
    eval $pushenv_list_var=\"\$$pushenv_list_var \$pushenv_var\"
}

prependenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    pushenvvar "$pushenv_var" "$pushenv_newval$pushenv_oldval"
}

popenv() {
    local pushenv_var=
    eval local pushenv_vars=\"\$pushenv_vars_${pushenv_level}\"
    for pushenv_var in $pushenv_vars; do
	local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
	local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
	eval local pushenv_save_val=\"\$$pushenv_save_var\"
	eval local pushenv_save_set=\"\${$pushenv_save_var+set}\"
	unset $pushenv_save_var
	unset $pushenv_savep_var
	if [ "$pushenv_save_set" = "set" ]; then
	    eval export $pushenv_var=\"\$pushenv_save_val\"
	else
	    unset $pushenv_var
	fi
    done
    unset pushenv_vars_${pushenv_level}
    if [ "$pushenv_level" = "0" ]; then
	error "Popping environment level 0"
    else
	pushenv_level=$(($pushenv_level - 1))
    fi
}

prepend_path() {
    if $(eval "test -n \"\$$1\""); then
	prependenvvar "$1" "$2:"
    else
	prependenvvar "$1" "$2"
    fi
}
pushenvvar CSL_SCRIPTDIR /scratch/paul/release/scripts
pushenvvar PATH /usr/local/tools/gcc-3.4.0/bin:/bin:/usr/bin
pushenvvar LD_LIBRARY_PATH /usr/local/tools/gcc-3.4.0/lib
pushenvvar XML_CATALOG_FILES '/usr/local/tools/gcc-3.4.0/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog'
clean_environment
mkdir -p /scratch/paul/release/symbianelf/obj
mkdir -p /scratch/paul/release/symbianelf/install
mkdir -p /scratch/paul/release/pkg
mkdir -p /scratch/paul/release/symbianelf/logs
rm -f /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf.src.tar.bz2 /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf.backup.tar.bz2
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup
rm -f /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf/binutils-2006q1-6.tar.bz2
pushd /scratch/paul/release/src
tar cf /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf/binutils-2006q1-6.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' binutils-2.17
popd
rm -f /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf/gcc-2006q1-6.tar.bz2
pushd /scratch/paul/release/src
tar cf /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf/gcc-2006q1-6.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' gcc-2006q1
popd
rm -f /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf/make-2006q1-6.tar.bz2
pushd /scratch/paul/release/src
tar cf /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf/make-2006q1-6.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' make-3.81
popd
rm -f /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/csl_docbook-2006q1-6.tar.bz2
pushd /scratch/paul/release/src
tar cf /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/csl_docbook-2006q1-6.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' csl-docbook-cvs
popd
rm -f /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/getting_started-2006q1-6.tar.bz2
pushd /scratch/paul/release/src
tar cf /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/getting_started-2006q1-6.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' getting-started-cvs
popd
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenv
pushenvvar CC i686-pc-linux-gnu-gcc
prepend_path PATH /scratch/paul/release/symbianelf/install/bin
rm -rf /scratch/paul/release/symbianelf/obj/getting_started-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/release/symbianelf/obj/getting_started-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/release/symbianelf/obj/getting_started-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/release/src/getting-started-cvs/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --with-release-config=2006Q1-arm-none-symbianelf '--with-target-name=ARM SymbianOS' --with-csl-docbook=/scratch/paul/release/src/csl-docbook-cvs --with-version-string=2006q1-6 --with-distribution=public '--with-xml-catalog-files=/usr/local/tools/gcc-3.4.0/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog'
make -j4
make prefix=/scratch/paul/release/symbianelf/install htmldir=/scratch/paul/release/symbianelf/install/share/doc/arm-2006q1-6-arm-none-symbianelf/html pdfdir=/scratch/paul/release/symbianelf/install/share/doc/arm-2006q1-6-arm-none-symbianelf/pdf install
popd
rm -rf /scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/paul/release/src/binutils-2.17 /scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
rm -rf /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --disable-nls --prefix=/opt/codesourcery --disable-werror
make -j4
make prefix=/scratch/paul/release/symbianelf/install htmldir=/scratch/paul/release/symbianelf/install/share/doc/arm-2006q1-6-arm-none-symbianelf/html pdfdir=/scratch/paul/release/symbianelf/install/share/doc/arm-2006q1-6-arm-none-symbianelf/pdf install
popd
pushd /scratch/paul/release/symbianelf/install
rm -f info/configure.info
rm -f info/standards.info
rm -f 'bin/*gccbug'
rm -f 'info/cppinternals.info*'
rm -f 'info/gccint.info*'
popd
copy_dir_clean /scratch/paul/release/src/binutils-2.17/include /scratch/paul/release/symbianelf/obj/host-libs-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
mkdir -p /scratch/paul/release/symbianelf/obj/host-libs-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu/libiberty/libiberty.a /scratch/paul/release/symbianelf/obj/host-libs-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
rm -rf /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu/gcc
cat > /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu/gcc/as <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/as "$@"
EOF0
chmod +x /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu/gcc/as
mkdir -p /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu/gcc
cat > /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu/gcc/collect-ld <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/ld "$@"
EOF0
chmod +x /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu/gcc/collect-ld
pushenv
pushd /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/paul/release/src/gcc-2006q1/configure --disable-nls --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --enable-languages=c,c++ --enable-shared --enable-threads --disable-libmudflap --disable-libssp --disable-libgomp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --prefix=/opt/codesourcery '--with-versuffix=CodeSourcery ARM 2006q1-6' --with-bugurl=mailto:arm-gnu@codesourcery.com
make -j4
make prefix=/scratch/paul/release/symbianelf/install htmldir=/scratch/paul/release/symbianelf/install/share/doc/arm-2006q1-6-arm-none-symbianelf/html pdfdir=/scratch/paul/release/symbianelf/install/share/doc/arm-2006q1-6-arm-none-symbianelf/pdf install
popd
popenv
pushd /scratch/paul/release/symbianelf/install
rm -f 'info/configure.info*'
rm -f 'info/standards.info*'
rm -f bin/arm-none-symbianelf-gccbug
rm -f info/cppinternals.info
rm -f info/gccint.info
popd
mkdir -p /scratch/paul/release/symbianelf/install
pushd /scratch/paul/release/symbianelf/install
rm -f 'info/configure.info*'
rm -f 'info/standards.info*'
rm -f 'bin/*gccbug'
rm -f 'info/cppinternals.info*'
rm -f 'info/gccint.info*'
popd
find /scratch/paul/release/symbianelf/install -name '*.la' -exec rm {} ';'
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-addr2line
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-ar
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-as
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-c++
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-c++filt
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-cpp
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-g++
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-gcc
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-gcc-4.1.0
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-gcov
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-gprof
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-ld
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-nm
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-objcopy
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-objdump
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-ranlib
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-readelf
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-size
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-strings
/usr/bin/strip /scratch/paul/release/symbianelf/install/bin/arm-none-symbianelf-strip
/usr/bin/strip /scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/ar
/usr/bin/strip /scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/as
/usr/bin/strip /scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/c++
/usr/bin/strip /scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/g++
/usr/bin/strip /scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/gcc
/usr/bin/strip /scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/ld
/usr/bin/strip /scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/nm
/usr/bin/strip /scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/objdump
/usr/bin/strip /scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/ranlib
/usr/bin/strip /scratch/paul/release/symbianelf/install/arm-none-symbianelf/bin/strip
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/release/symbianelf/install/arm-none-symbianelf/lib/libsupc++.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/release/symbianelf/install/arm-none-symbianelf/lib/softfp/libsupc++.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/release/symbianelf/install/lib/gcc/arm-none-symbianelf/4.1.0/libgcov.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/release/symbianelf/install/lib/gcc/arm-none-symbianelf/4.1.0/libgcc.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/release/symbianelf/install/lib/gcc/arm-none-symbianelf/4.1.0/softfp/libgcov.a || true
arm-none-symbianelf-objcopy -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc -R .comment -R .note /scratch/paul/release/symbianelf/install/lib/gcc/arm-none-symbianelf/4.1.0/softfp/libgcc.a || true
rm -f /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2
pushd /scratch/paul/release/symbianelf/install
tar cjf /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --owner=0 --group=0 .
popd
/scratch/paul/release/scripts/gnu-rpm-inst -h i686-pc-linux-gnu -p /scratch/paul/release/pkg -o /scratch/paul/release/symbianelf/obj/rpm-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu -i /opt/codesourcery 2006Q1-arm-none-symbianelf.cfg
popenv
pushenv
pushenvvar CC i686-mingw32-gcc
rm -rf /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-i686-mingw32
mkdir /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-i686-mingw32
tar xf /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --bzip2
popd
prepend_path PATH /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-i686-mingw32/bin
rm -rf /scratch/paul/release/symbianelf/obj/getting_started-2006q1-6-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/release/symbianelf/obj/getting_started-2006q1-6-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/release/symbianelf/obj/getting_started-2006q1-6-arm-none-symbianelf-i686-mingw32
/scratch/paul/release/src/getting-started-cvs/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/opt/codesourcery --with-release-config=2006Q1-arm-none-symbianelf '--with-target-name=ARM SymbianOS' --with-csl-docbook=/scratch/paul/release/src/csl-docbook-cvs --with-version-string=2006q1-6 --with-distribution=public '--with-xml-catalog-files=/usr/local/tools/gcc-3.4.0/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog'
make -j4
make prefix=/scratch/paul/release/symbianelf/install/host-i686-mingw32 htmldir=/scratch/paul/release/symbianelf/install/host-i686-mingw32/share/doc/arm-2006q1-6-arm-none-symbianelf/html pdfdir=/scratch/paul/release/symbianelf/install/host-i686-mingw32/share/doc/arm-2006q1-6-arm-none-symbianelf/pdf install
popd
rm -rf /scratch/paul/release/symbianelf/obj/make-src-2006q1-6-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/paul/release/src/make-3.81 /scratch/paul/release/symbianelf/obj/make-src-2006q1-6-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/paul/release/symbianelf/obj/make-src-2006q1-6-arm-none-symbianelf-i686-mingw32
rm -rf /scratch/paul/release/symbianelf/obj/make-2006q1-6-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/release/symbianelf/obj/make-2006q1-6-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/release/symbianelf/obj/make-2006q1-6-arm-none-symbianelf-i686-mingw32
/scratch/paul/release/symbianelf/obj/make-src-2006q1-6-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/opt/codesourcery --disable-nls
make -j4
make prefix=/scratch/paul/release/symbianelf/install/host-i686-mingw32 htmldir=/scratch/paul/release/symbianelf/install/host-i686-mingw32/share/doc/arm-2006q1-6-arm-none-symbianelf/html pdfdir=/scratch/paul/release/symbianelf/install/host-i686-mingw32/share/doc/arm-2006q1-6-arm-none-symbianelf/pdf install
popd
rm -rf /scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/paul/release/src/binutils-2.17 /scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-i686-mingw32
rm -rf /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-i686-mingw32
pushd /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-i686-mingw32
/scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --prefix=/opt/codesourcery --disable-nls --prefix=/opt/codesourcery --disable-werror
make -j4
make prefix=/scratch/paul/release/symbianelf/install/host-i686-mingw32 htmldir=/scratch/paul/release/symbianelf/install/host-i686-mingw32/share/doc/arm-2006q1-6-arm-none-symbianelf/html pdfdir=/scratch/paul/release/symbianelf/install/host-i686-mingw32/share/doc/arm-2006q1-6-arm-none-symbianelf/pdf install
popd
pushd /scratch/paul/release/symbianelf/install/host-i686-mingw32
rm -f info/configure.info
rm -f info/standards.info
rm -f 'bin/*gccbug'
rm -f 'info/cppinternals.info*'
rm -f 'info/gccint.info*'
popd
copy_dir_clean /scratch/paul/release/src/binutils-2.17/include /scratch/paul/release/symbianelf/obj/host-libs-2006q1-6-arm-none-symbianelf-i686-mingw32/usr/include
mkdir -p /scratch/paul/release/symbianelf/obj/host-libs-2006q1-6-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-i686-mingw32/libiberty/libiberty.a /scratch/paul/release/symbianelf/obj/host-libs-2006q1-6-arm-none-symbianelf-i686-mingw32/usr/lib
rm -rf /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-mingw32/gcc
cat > /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-mingw32/gcc/as <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin/as "$@"
EOF0
chmod +x /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-mingw32/gcc/as
mkdir -p /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-mingw32/gcc
cat > /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-mingw32/gcc/collect-ld <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin/ld "$@"
EOF0
chmod +x /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-mingw32/gcc/collect-ld
pushenv
pushd /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-i686-mingw32
/scratch/paul/release/src/gcc-2006q1/configure --disable-nls --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --enable-languages=c,c++ --enable-shared --enable-threads --disable-libmudflap --disable-libssp --disable-libgomp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --prefix=/opt/codesourcery '--with-versuffix=CodeSourcery ARM 2006q1-6' --with-bugurl=mailto:arm-gnu@codesourcery.com
make -j4 all-gcc
make prefix=/scratch/paul/release/symbianelf/install/host-i686-mingw32 htmldir=/scratch/paul/release/symbianelf/install/host-i686-mingw32/share/doc/arm-2006q1-6-arm-none-symbianelf/html pdfdir=/scratch/paul/release/symbianelf/install/host-i686-mingw32/share/doc/arm-2006q1-6-arm-none-symbianelf/pdf install-gcc
popd
popenv
pushd /scratch/paul/release/symbianelf/install/host-i686-mingw32
rm -f 'info/configure.info*'
rm -f 'info/standards.info*'
rm -f bin/arm-none-symbianelf-gccbug
rm -f info/cppinternals.info
rm -f info/gccint.info
popd
copy_dir /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-i686-mingw32/lib/gcc/arm-none-symbianelf /scratch/paul/release/symbianelf/install/host-i686-mingw32/lib/gcc/arm-none-symbianelf
copy_dir /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/lib /scratch/paul/release/symbianelf/install/host-i686-mingw32/arm-none-symbianelf/lib
copy_dir /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-i686-mingw32/include/c++ /scratch/paul/release/symbianelf/install/host-i686-mingw32/include/c++
mkdir -p /scratch/paul/release/symbianelf/install/host-i686-mingw32
pushd /scratch/paul/release/symbianelf/install/host-i686-mingw32
rm -f 'info/configure.info*'
rm -f 'info/standards.info*'
rm -f 'bin/*gccbug'
rm -f 'info/cppinternals.info*'
rm -f 'info/gccint.info*'
popd
find /scratch/paul/release/symbianelf/install/host-i686-mingw32 -name '*.la' -exec rm {} ';'
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-addr2line.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-ar.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-as.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-c++.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-c++filt.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-cpp.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-g++.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-gcc-4.1.0
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-gcc.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-gcov.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-gprof.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-ld.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-nm.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-objcopy.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-objdump.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-ranlib.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-readelf.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-size.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-strings.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/arm-none-symbianelf-strip.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/bin/make.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/arm-none-symbianelf/bin/ar.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/arm-none-symbianelf/bin/as.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/arm-none-symbianelf/bin/c++.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/arm-none-symbianelf/bin/g++.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/arm-none-symbianelf/bin/gcc.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/arm-none-symbianelf/bin/ld.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/arm-none-symbianelf/bin/nm.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/arm-none-symbianelf/bin/objdump.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/arm-none-symbianelf/bin/ranlib.exe
i686-mingw32-strip /scratch/paul/release/symbianelf/install/host-i686-mingw32/arm-none-symbianelf/bin/strip.exe
rm -f /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf-i686-mingw32.tar.bz2
pushd /scratch/paul/release/symbianelf/install/host-i686-mingw32
tar cjf /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf-i686-mingw32.tar.bz2 --owner=0 --group=0 -h .
popd
/scratch/paul/release/scripts/gnu-wininst -p /scratch/paul/release/pkg 2006Q1-arm-none-symbianelf.cfg
popenv
pushenv
pushenvvar CC sparc-sun-solaris2.8-gcc
rm -rf /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
mkdir /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
pushd /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
tar xf /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --bzip2
popd
prepend_path PATH /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/bin
rm -rf /scratch/paul/release/symbianelf/obj/getting_started-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
mkdir -p /scratch/paul/release/symbianelf/obj/getting_started-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
pushd /scratch/paul/release/symbianelf/obj/getting_started-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
/scratch/paul/release/src/getting-started-cvs/configure --build=i686-pc-linux-gnu --host=sparc-sun-solaris2.8 --target=arm-none-symbianelf --prefix=/opt/codesourcery --with-release-config=2006Q1-arm-none-symbianelf '--with-target-name=ARM SymbianOS' --with-csl-docbook=/scratch/paul/release/src/csl-docbook-cvs --with-version-string=2006q1-6 --with-distribution=public '--with-xml-catalog-files=/usr/local/tools/gcc-3.4.0/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog'
make -j4
make prefix=/scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8 htmldir=/scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q1-6-arm-none-symbianelf/html pdfdir=/scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q1-6-arm-none-symbianelf/pdf install
popd
rm -rf /scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
copy_dir_clean /scratch/paul/release/src/binutils-2.17 /scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
chmod -R u+w /scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
rm -rf /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
mkdir -p /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
pushd /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
/scratch/paul/release/symbianelf/obj/binutils-src-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/configure --build=i686-pc-linux-gnu --host=sparc-sun-solaris2.8 --target=arm-none-symbianelf --prefix=/opt/codesourcery --disable-nls --prefix=/opt/codesourcery --disable-werror
make -j4
make prefix=/scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8 htmldir=/scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q1-6-arm-none-symbianelf/html pdfdir=/scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q1-6-arm-none-symbianelf/pdf install
popd
pushd /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8
rm -f info/configure.info
rm -f info/standards.info
rm -f 'bin/*gccbug'
rm -f 'info/cppinternals.info*'
rm -f 'info/gccint.info*'
popd
copy_dir_clean /scratch/paul/release/src/binutils-2.17/include /scratch/paul/release/symbianelf/obj/host-libs-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/usr/include
mkdir -p /scratch/paul/release/symbianelf/obj/host-libs-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/usr/lib
cp /scratch/paul/release/symbianelf/obj/binutils-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/libiberty/libiberty.a /scratch/paul/release/symbianelf/obj/host-libs-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/usr/lib
rm -rf /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
mkdir -p /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
mkdir -p /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/gcc
cat > /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/gcc/as <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/arm-none-symbianelf/bin/as "$@"
EOF0
chmod +x /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/gcc/as
mkdir -p /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/gcc
cat > /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/gcc/collect-ld <<'EOF0'
#!/usr/bin/env bash
/scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/arm-none-symbianelf/bin/ld "$@"
EOF0
chmod +x /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/gcc/collect-ld
pushenv
pushd /scratch/paul/release/symbianelf/obj/gcc-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8
/scratch/paul/release/src/gcc-2006q1/configure --disable-nls --build=i686-pc-linux-gnu --host=sparc-sun-solaris2.8 --target=arm-none-symbianelf --enable-languages=c,c++ --enable-shared --enable-threads --disable-libmudflap --disable-libssp --disable-libgomp --disable-libstdcxx-pch --with-gnu-as --with-gnu-ld --prefix=/opt/codesourcery '--with-versuffix=CodeSourcery ARM 2006q1-6' --with-bugurl=mailto:arm-gnu@codesourcery.com
make -j4 all-gcc
make prefix=/scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8 htmldir=/scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q1-6-arm-none-symbianelf/html pdfdir=/scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/share/doc/arm-2006q1-6-arm-none-symbianelf/pdf install-gcc
popd
popenv
pushd /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8
rm -f 'info/configure.info*'
rm -f 'info/standards.info*'
rm -f bin/arm-none-symbianelf-gccbug
rm -f info/cppinternals.info
rm -f info/gccint.info
popd
copy_dir /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/lib/gcc/arm-none-symbianelf /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/lib/gcc/arm-none-symbianelf
copy_dir /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/arm-none-symbianelf/lib /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/lib
copy_dir /scratch/paul/release/symbianelf/obj/tools-i686-pc-linux-gnu-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8/include/c++ /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/include/c++
mkdir -p /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8
pushd /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8
rm -f 'info/configure.info*'
rm -f 'info/standards.info*'
rm -f 'bin/*gccbug'
rm -f 'info/cppinternals.info*'
rm -f 'info/gccint.info*'
popd
find /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8 -name '*.la' -exec rm {} ';'
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-addr2line
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-ar
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-as
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-c++
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-c++filt
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-cpp
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-g++
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-gcc
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-gcc-4.1.0
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-gcov
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-gprof
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-ld
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-nm
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-objcopy
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-objdump
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-ranlib
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-readelf
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-size
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-strings
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/bin/arm-none-symbianelf-strip
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/ar
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/as
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/c++
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/g++
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/gcc
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/ld
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/nm
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/objdump
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/ranlib
sparc-sun-solaris2.8-strip /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8/arm-none-symbianelf/bin/strip
rm -f /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8.tar.bz2
pushd /scratch/paul/release/symbianelf/install/host-sparc-sun-solaris2.8
tar cjf /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf-sparc-sun-solaris2.8.tar.bz2 --owner=0 --group=0 .
popd
popenv
cat > /scratch/paul/release/symbianelf/obj/gnu-2006q1-6.txt <<'EOF0'
Version Information
===================

Version:           2006q1-6
Host(s):           i686-pc-linux-gnu i686-mingw32 sparc-sun-solaris2.8
Target:            arm-none-symbianelf

Build Information
=================

Build date:             20060606 16:05:49
Build machine:          sparrowhawk.codesourcery.com
Build operating system: Red Hat Enterprise Linux ES release 4 (Nahant Update 3)
Build uname:            Linux sparrowhawk.codesourcery.com 2.6.9-34.0.1.ELsmp #1 SMP Wed May 17 16:59:36 EDT 2006 x86_64 unknown unknown GNU/Linux
Build user:             paul

EOF0
rm -rf /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts
mkdir /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-release /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-release
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-common /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-common
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-test /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-test
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-test-glibc /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-test-glibc
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-logconv-glibc /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-logconv-glibc
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-logconv-openposix /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-logconv-openposix
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-logconv-xfail /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-logconv-xfail
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-rpm-inst /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-rpm-inst
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/build-rpm-installer /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/build-rpm-installer
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-wininst /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-wininst
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-wininst-helper /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-wininst-helper
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/libwininst /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/libwininst
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-mod-binutils /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-mod-binutils
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-mod-gcc /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-mod-gcc
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-mod-make /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-mod-make
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-mod-csl_docbook /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-mod-csl_docbook
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/.
cp /scratch/paul/release/scripts/gnu-mod-getting_started /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/gnu-mod-getting_started
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/release/scripts/release-configs/2006Q1-arm-none-symbianelf.cfg /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/release-configs/2006Q1-arm-none-symbianelf.cfg
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/release/scripts/release-configs/2006Q1-arm.inc /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/release-configs/2006Q1-arm.inc
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/release/scripts/release-configs/4.1-sourceryg++.inc /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/release-configs/4.1-sourceryg++.inc
mkdir -p /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/release-configs
cp /scratch/paul/release/scripts/release-configs/docs.inc /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf.backup/scripts/release-configs/docs.inc
pushd /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf
tar cjf /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf.backup.tar.bz2 --owner=0 --group=0 arm-2006q1-6-arm-none-symbianelf.backup
popd
cp /scratch/paul/release/symbianelf/obj/gnu-2006q1-6.txt /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf
cp /scratch/paul/release/symbianelf/logs/arm-2006q1-6-arm-none-symbianelf.sh /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf/arm-2006q1-6-arm-none-symbianelf
pushd /scratch/paul/release/symbianelf/obj/pkg-2006q1-6-arm-none-symbianelf
tar cjf /scratch/paul/release/pkg/arm-2006q1-6-arm-none-symbianelf.src.tar.bz2 --owner=0 --group=0 arm-2006q1-6-arm-none-symbianelf
popd
